==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/elastic/kotlin/OpenAI.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.elastic.kotlin

import com.pulumi.azurenative.elastic.kotlin.outputs.OpenAIIntegrationPropertiesResponse
import com.pulumi.azurenative.elastic.kotlin.outputs.OpenAIIntegrationPropertiesResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [OpenAI].
 */
@PulumiTagMarker
public class OpenAIResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: OpenAIArgs = OpenAIArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend OpenAIArgsBuilder.() -> Unit) {
        val builder = OpenAIArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): OpenAI {
        val builtJavaResource = com.pulumi.azurenative.elastic.OpenAI(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return OpenAI(builtJavaResource)
    }
}

/**
 * Capture properties of Open AI resource Integration.
 * Azure REST API version: 2024-03-01.
 * Other available API versions: 2024-01-01-preview.
 * ## Example Usage
 * ### OpenAI_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var openAI = new AzureNative.Elastic.OpenAI("openAI", new()
 *     {
 *         IntegrationName = "default",
 *         MonitorName = "myMonitor",
 *         ResourceGroupName = "myResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/elastic/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := elastic.NewOpenAI(ctx, "openAI", &elastic.OpenAIArgs{
 * 			IntegrationName:   pulumi.String("default"),
 * 			MonitorName:       pulumi.String("myMonitor"),
 * 			ResourceGroupName: pulumi.String("myResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.elastic.OpenAI;
 * import com.pulumi.azurenative.elastic.OpenAIArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var openAI = new OpenAI("openAI", OpenAIArgs.builder()
 *             .integrationName("default")
 *             .monitorName("myMonitor")
 *             .resourceGroupName("myResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:elastic:OpenAI default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Elastic/monitors/{monitorName}/openAIIntegrations/{integrationName}
 * ```
 */
public class OpenAI internal constructor(
    override val javaResource: com.pulumi.azurenative.elastic.OpenAI,
) : KotlinCustomResource(javaResource, OpenAIMapper) {
    /**
     * Name of the integration.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Open AI Integration details.
     */
    public val properties: Output<OpenAIIntegrationPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the integration.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object OpenAIMapper : ResourceMapper<OpenAI> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.elastic.OpenAI::class == javaResource::class

    override fun map(javaResource: Resource): OpenAI = OpenAI(
        javaResource as
            com.pulumi.azurenative.elastic.OpenAI,
    )
}

/**
 * @see [OpenAI].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [OpenAI].
 */
public suspend fun openAI(name: String, block: suspend OpenAIResourceBuilder.() -> Unit): OpenAI {
    val builder = OpenAIResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [OpenAI].
 * @param name The _unique_ name of the resulting resource.
 */
public fun openAI(name: String): OpenAI {
    val builder = OpenAIResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/elastic/kotlin/OpenAI.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.elastic.kotlin

import com.pulumi.azurenative.elastic.kotlin.outputs.OpenAIIntegrationPropertiesResponse
import com.pulumi.azurenative.elastic.kotlin.outputs.OpenAIIntegrationPropertiesResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [OpenAI].
 */
@PulumiTagMarker
public class OpenAIResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: OpenAIArgs = OpenAIArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend OpenAIArgsBuilder.() -> Unit) {
        val builder = OpenAIArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): OpenAI {
        val builtJavaResource = com.pulumi.azurenative.elastic.OpenAI(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return OpenAI(builtJavaResource)
    }
}

/**
 * Capture properties of Open AI resource Integration.
 * Azure REST API version: 2024-03-01.
 * Other available API versions: 2024-01-01-preview.
 * ## Example Usage
 * ### OpenAI_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var openAI = new AzureNative.Elastic.OpenAI("openAI", new()
 *     {
 *         IntegrationName = "default",
 *         MonitorName = "myMonitor",
 *         ResourceGroupName = "myResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/elastic/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := elastic.NewOpenAI(ctx, "openAI", &elastic.OpenAIArgs{
 * 			IntegrationName:   pulumi.String("default"),
 * 			MonitorName:       pulumi.String("myMonitor"),
 * 			ResourceGroupName: pulumi.String("myResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.elastic.OpenAI;
 * import com.pulumi.azurenative.elastic.OpenAIArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var openAI = new OpenAI("openAI", OpenAIArgs.builder()
 *             .integrationName("default")
 *             .monitorName("myMonitor")
 *             .resourceGroupName("myResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:elastic:OpenAI default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Elastic/monitors/{monitorName}/openAIIntegrations/{integrationName}
 * ```
 */
public class OpenAI internal constructor(
    override val javaResource: com.pulumi.azurenative.elastic.OpenAI,
) : KotlinCustomResource(javaResource, OpenAIMapper) {
    /**
     * Name of the integration.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Open AI Integration details.
     */
    public val properties: Output<OpenAIIntegrationPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the integration.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object OpenAIMapper : ResourceMapper<OpenAI> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.elastic.OpenAI::class == javaResource::class

    override fun map(javaResource: Resource): OpenAI = OpenAI(
        javaResource as
            com.pulumi.azurenative.elastic.OpenAI,
    )
}

/**
 * @see [OpenAI].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [OpenAI].
 */
public suspend fun openAI(name: String, block: suspend OpenAIResourceBuilder.() -> Unit): OpenAI {
    val builder = OpenAIResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [OpenAI].
 * @param name The _unique_ name of the resulting resource.
 */
public fun openAI(name: String): OpenAI {
    val builder = OpenAIResourceBuilder()
    builder.name(name)
    return builder.build()
}
